# Contributing to dataflake projects

The projects under the dataflake GitHub organization are open source and
welcome contributions in different forms:

* bug reports
* code improvements and bug fixes
* documentation improvements
